import {
  Box,
  Button,
  List,
  ListItemButton,
  ListItemText,
  Paper,
  Typography,
} from "@mui/material";
import { BackButton, Sight, TabPanel } from "@shared";
import { SightEdit } from "@widgets";
import { Plus } from "lucide-react";
import { useState } from "react";

// Мокап данных для списка блоков правого виджета
const mockRightWidgetBlocks = [
  { id: "preview_media", name: "Превью-медиа", type: "special" }, // Особый блок?
  { id: "article_1", name: "1. История", type: "article" },
  { id: "article_2", name: "2. Факты", type: "article" },
  {
    id: "article_3",
    name: "3. Блокада (Пример длинного названия)",
    type: "article",
  },
];

// Мокап данных для выбранного блока для редактирования
// В реальности это будет объект Article из API
const mockSelectedBlockData = {
  id: "article_1",
  heading: "История основания Санкт-Петербурга",
  body: "## Начало\nГород был основан 27 мая 1703 года Петром I...",
  media: [
    // Предполагаем, что у статьи может быть несколько медиа
    // { id: "media_1", url: "https://via.placeholder.com/300x200.png?text=History+Image+1", type: "image" }
  ],
};

export const RightWidgetTab = ({
  value,
  index,
  data,
}: {
  value: number;
  index: number;
  data?: Sight;
}) => {
  const [rightWidgetBlocks, setRightWidgetBlocks] = useState(
    mockRightWidgetBlocks
  );
  const [selectedBlockId, setSelectedBlockId] = useState<string | null>(
    mockRightWidgetBlocks[1]?.id || null
  ); // Выбираем первый "article" по умолчанию

  const handleSelectBlock = (blockId: string) => {
    setSelectedBlockId(blockId);
    // Здесь будет логика загрузки данных для выбранного блока, если они не загружены
    console.log("Selected block:", blockId);
  };

  const handleAddBlock = () => {
    // Логика открытия модала/формы для создания нового блока/статьи
    // или выбора существующей статьи для привязки
    console.log("Add new block");
    const newBlockId = `article_${Date.now()}`;
    setRightWidgetBlocks([
      ...rightWidgetBlocks,
      {
        id: newBlockId,
        name: `${
          rightWidgetBlocks.filter((b) => b.type === "article").length + 1
        }. Новый блок`,
        type: "article",
      },
    ]);
    setSelectedBlockId(newBlockId);
  };

  const handleSave = () => {
    console.log("Saving right widget...");
  };

  // Находим данные для редактирования на основе selectedBlockId
  // В реальном приложении эти данные будут приходить из store или загружаться по API
  const currentBlockToEdit =
    selectedBlockId === mockSelectedBlockData.id
      ? mockSelectedBlockData
      : selectedBlockId
      ? {
          id: selectedBlockId,
          heading:
            rightWidgetBlocks.find((b) => b.id === selectedBlockId)?.name ||
            "Заголовок...",
          body: "Содержимое...",
          media: [],
        }
      : null;

  return (
    <TabPanel value={value} index={index}>
      <Box
        sx={{
          display: "flex",
          flexDirection: "column",
          height: "100%",
          minHeight: "calc(100vh - 200px)",
          gap: 2,
          paddingBottom: "70px",
          position: "relative",
        }}
      >
        <BackButton />

        <Box sx={{ display: "flex", flexGrow: 1, gap: 2.5 }}>
          {/* Левая колонка: Список блоков/статей */}
          <Paper
            elevation={2}
            sx={{
              width: 260, // Ширина как на макете
              minWidth: 240,
              display: "flex",
              flexDirection: "column",
              justifyContent: "space-between",
              padding: 1.5,
              borderRadius: 2,
              border: "1px solid",
              borderColor: "divider",
            }}
          >
            <List
              dense
              sx={{
                overflowY: "auto",
                flexGrow: 1,
                maxHeight:
                  "calc(100% - 60px)" /* Adjust based on button size */,
              }}
            >
              {rightWidgetBlocks.map((block) => (
                <ListItemButton
                  key={block.id}
                  selected={selectedBlockId === block.id}
                  onClick={() => handleSelectBlock(block.id)}
                  sx={{
                    borderRadius: 1,
                    mb: 0.5,
                    backgroundColor:
                      selectedBlockId === block.id
                        ? "primary.light"
                        : "transparent",
                    "&.Mui-selected": {
                      backgroundColor: "primary.main",
                      color: "primary.contrastText",
                      "&:hover": {
                        backgroundColor: "primary.dark",
                      },
                    },
                    "&:hover": {
                      backgroundColor:
                        selectedBlockId !== block.id
                          ? "action.hover"
                          : undefined,
                    },
                  }}
                >
                  <ListItemText
                    primary={block.name}
                    primaryTypographyProps={{
                      fontWeight:
                        selectedBlockId === block.id ? "bold" : "normal",
                      overflow: "hidden",
                      textOverflow: "ellipsis",
                      whiteSpace: "nowrap",
                    }}
                  />
                </ListItemButton>
              ))}
            </List>
            <Box
              sx={{
                display: "flex",
                justifyContent: "center",
                pt: 1.5,
                borderTop: "1px solid",
                borderColor: "divider",
              }}
            >
              <Button
                variant="contained"
                onClick={handleAddBlock}
                startIcon={<Plus />}
                fullWidth
              >
                Добавить блок
              </Button>
            </Box>
          </Paper>

          {/* Правая колонка: Редактор выбранного блока (SightEdit) */}
          <Paper
            elevation={2}
            sx={{
              flexGrow: 1,
              padding: 2.5,
              borderRadius: 2,
              border: "1px solid",
              borderColor: "divider",
              overflowY: "auto", // Если контент будет больше
            }}
          >
            {currentBlockToEdit ? (
              <>
                <SightEdit
                  onUnlink={() => console.log("Unlink block:", selectedBlockId)}
                  onDelete={() => {
                    console.log("Delete block:", selectedBlockId);
                    setRightWidgetBlocks((blocks) =>
                      blocks.filter((b) => b.id !== selectedBlockId)
                    );
                    setSelectedBlockId(null);
                  }}
                />
                <Paper elevation={1} sx={{ padding: 2, mt: 1, width: "75%" }}>
                  <Typography variant="h6" gutterBottom>
                    МЕДИА
                  </Typography>
                  {/* Здесь будет UI для управления медиа статьи */}
                  <Box
                    sx={{
                      width: "100%",
                      height: 100,
                      backgroundColor: "grey.100",
                      display: "flex",
                      alignItems: "center",
                      justifyContent: "center",
                      borderRadius: 1,
                      mb: 1,
                      border: "2px dashed",
                      borderColor: "grey.300",
                    }}
                  >
                    <Typography color="text.secondary">Нет медиа</Typography>
                  </Box>

                  <Button variant="contained">Выбрать/Загрузить медиа</Button>
                </Paper>
              </>
            ) : (
              <></>
            )}
          </Paper>
        </Box>

        {/* Блок МЕДИА для статьи */}

        <Box sx={{ position: "absolute", bottom: 0, right: 0, padding: 2 }}>
          <Button variant="contained" color="success" onClick={handleSave}>
            Сохранить
          </Button>
        </Box>
      </Box>
    </TabPanel>
  );
};
